Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrFileOverDir = errors.New(
"fsync: trying to overwrite a non-empty directory with a file")
)
Functions ¶
Types ¶
type Syncer ¶
type Syncer struct {
// Set this to true to delete files in the destination that don't exist
// in the source.
Delete bool
// By default, modification times are synced. This can be turned off by
// setting this to true.
NoTimes bool
SrcFs afero.Fs
DestFs afero.Fs
}
Type Syncer provides functions for syncing files.
func NewSyncer ¶
func NewSyncer() *Syncer
NewSyncer creates a new instance of Syncer with default options.
Click to show internal directories.
Click to hide internal directories.